@@ -1,6 +1,5 @@
 use pnet::{datalink::NetworkInterface, packet::tcp::MutableTcpPacket};
-use python_comm::prelude::raise_error;
-use python_comm_macros::auto_func_name2;
+use python_comm::raise_error_use::*;
 use rand::{rngs::ThreadRng, thread_rng, Rng};
 use rawsocket_helper::{
     out_going::{get_iface_by_name, get_ifaces},
@@ -24,7 +23,7 @@ fn main() {
 }
 
 /// 含错误信息的入口
-#[auto_func_name2]
+#[auto_func_name]
 fn main_error() -> Result<(), anyhow::Error> {
     println!("命令: {}", env::args().collect::<Vec<String>>().join(" "));
 
@@ -40,7 +39,7 @@ fn main_error() -> Result<(), anyhow::Error> {
     // 检查接口名称
     let if_name = env::args()
         .nth(1)
-        .ok_or_else(|| raise_error!(__func__, format!("缺少命令行参数:\n{}", usage.clone())))?;
+        .ok_or_else(|| raise_error!("raw", __func__, format!("缺少命令行参数:\n{}", usage.clone())))?;
 
     // 列表
     if if_name == "list" {
@@ -51,13 +50,13 @@ fn main_error() -> Result<(), anyhow::Error> {
     }
 
     // 匹配接口名称
-    let (iface, src_ip) = get_iface_by_name(&if_name).ok_or_else(|| raise_error!(__func__, "查不到指定接口"))?;
-    let src_ip = src_ip.ok_or_else(|| raise_error!(__func__, "指定接口查不到 IPv4 地址"))?;
+    let (iface, src_ip) = get_iface_by_name(&if_name).ok_or_else(|| raise_error!("raw", __func__, "查不到指定接口"))?;
+    let src_ip = src_ip.ok_or_else(|| raise_error!("raw", __func__, "指定接口查不到 IPv4 地址"))?;
 
     // 检查 MAC 地址，应晚于 get_iface_and_ip 否则 list 不能给出正确提示
     let gw_mac = env::args()
         .nth(2)
-        .ok_or_else(|| raise_error!(__func__, format!("缺少命令行参数:\n{}", usage.clone())))?;
+        .ok_or_else(|| raise_error!("raw", __func__, format!("缺少命令行参数:\n{}", usage.clone())))?;
 
     let mut rng = thread_rng();
 
@@ -83,7 +82,7 @@ fn main_error() -> Result<(), anyhow::Error> {
 }
 
 /// 通过 pnet L2 通道发送
-#[auto_func_name2]
+#[auto_func_name]
 fn send_l2(
     iface: &NetworkInterface,
     gw_mac: &str,
@@ -92,7 +91,9 @@ fn send_l2(
 ) -> Result<(), anyhow::Error> {
     let (mut tx, mut _rx) = create_l2_channel(iface).or_else(|err| raise_error!(__func__, "\n", err))?;
 
-    let src_mac = iface.mac.ok_or_else(|| raise_error!(__func__, "无法获取源 MAC 地址"))?;
+    let src_mac = iface
+        .mac
+        .ok_or_else(|| raise_error!("raw", __func__, "无法获取源 MAC 地址"))?;
     let dst_mac = parse_mac(gw_mac);
     let dst_ip = Ipv4Addr::new(rng.gen::<u8>(), rng.gen::<u8>(), rng.gen::<u8>(), rng.gen::<u8>());
     let src_port = rng.gen::<u16>();
@@ -114,7 +115,7 @@ fn send_l2(
 }
 
 /// 通过 pnet L4 通道发送
-#[auto_func_name2]
+#[auto_func_name]
 fn send_l4(src_ip: &Ipv4Addr, mut rng: &mut ThreadRng) -> Result<(), anyhow::Error> {
     let (mut tx, mut _rx) = create_l4_channel().or_else(|err| raise_error!(__func__, "\n", err))?;
 
@@ -124,7 +125,7 @@ fn send_l4(src_ip: &Ipv4Addr, mut rng: &mut ThreadRng) -> Result<(), anyhow::Err
 
     let mut tx_buffer = [0u8; 20];
     let mut tx_packet =
-        MutableTcpPacket::new(&mut tx_buffer).ok_or_else(|| raise_error!(__func__, "无法创建 TcpPacket"))?;
+        MutableTcpPacket::new(&mut tx_buffer).ok_or_else(|| raise_error!("raw", __func__, "无法创建 TcpPacket"))?;
     build_l4_tcp_packet(&mut tx_packet, &src_ip, &dst_ip, src_port, dst_port, &mut rng);
 
     tx.send_to(tx_packet, IpAddr::V4(dst_ip))
